@@ -1,7 +1,7 @@
 package Template::Caribou::Tags;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: generates tags functions for Caribou templates
-$Template::Caribou::Tags::VERSION = '1.2.0';
+$Template::Caribou::Tags::VERSION = '1.2.1';
 
 use strict;
 use warnings;
@@ -11,6 +11,7 @@ use Carp;
 use Template::Caribou::Role;
 
 use List::AllUtils qw/ pairmap pairgrep /;
+use Ref::Util qw/ is_plain_hashref /;
 
 use parent 'Exporter::Tiny';
 use experimental 'signatures', 'postderef';
@@ -120,7 +121,7 @@ sub render_tag {
     my $writer = XML::Writer->new(OUTPUT => 'self', UNSAFE => 1);
     my @attributes = pairmap { (  $a => $b ) x (length $b > 0) }
         map { 
-            $_ => ref $_{$_} 
+            $_ => is_plain_hashref($_{$_})
                 ? join ' ', sort { $a cmp $b } pairmap { $a } pairgrep { $b } $_{$_}->%* 
                 : $_{$_} 
         }
@@ -165,7 +166,7 @@ Template::Caribou::Tags - generates tags functions for Caribou templates
 
 =head1 VERSION
 
-version 1.2.0
+version 1.2.1
 
 =head1 SYNOPSIS
 
