@@ -3,15 +3,12 @@ package UseCase::Two;
 use strict;
 use warnings;
 
-use Moose;
-
-use Template::Caribou::Utils;
-use Template::Caribou::Tags qw/ attr /;
+use Template::Caribou;
 use Template::Caribou::Tags::HTML qw/ :all /;
 
-with 'Template::Caribou';
 with 'Template::Caribou::Files' => {
     dirs => [ 't/corpus/usecase_2' ],
+    intro => [ 'use strict;  use warnings;' ],
 };
 
 1;
